==> adsprod-facade-1.2.26-sources.jar: com/bxm/adsprod/facade/award/AwardDto.java <==
package com.bxm.adsprod.facade.award;

import com.bxm.warcar.validate.annotation.DefaultValue;
import com.bxm.warcar.validate.annotation.ValidateImeiOrIdfa;
import com.bxm.warcar.validate.annotation.ValidateLength;
import com.bxm.warcar.validate.annotation.ValidateNotNull;
import org.apache.commons.lang3.StringUtils;

import java.io.Serializable;

/**
 * 抽奖数据传输对象
 *
 * @ClassName AwardDto
 * @CopyRright (c) 2018-bxm：杭州微财网络科技有限公司
 * @Author kk.xie
 * @Date 2018/7/20 18:15
 * @Version 1.0
 * @Modifier kk.xie
 * @Modify Date 2018/7/20 18:15
 **/
public class AwardDto implements Serializable{
    private static final long serialVersionUID = 2955004102853948797L;

    /**
     *  弹窗类型  0-出券弹窗 1-首页弹窗 2-挽留弹窗
     */
    @DefaultValue("0")
    @ValidateNotNull
    private Integer scene;

    /**
     * 媒体
     */
    @DefaultValue("mistake_appKey")
    @ValidateLength(min = 32, max = 32)
    private String appkey;

    /**
     * 渠道
     */
    @DefaultValue("1")
    @ValidateNotNull
    private Integer appEntrance;

    /**
     * 用户ID
     */
    @DefaultValue("mistake_uid")
    @ValidateNotNull
    private String uid;

    /**
     * 渠道
     */
    @DefaultValue("mistake_biz")
    @ValidateNotNull
    private String business;

    /**
     * IMEI 安卓唯一标识码
     */
    @ValidateImeiOrIdfa
    private String i;

    /**
     * IDFA 苹果唯一标识符
     */
    @ValidateImeiOrIdfa
    private String f;

    /**
     * 活动ID
     */
    @DefaultValue("0")
    @ValidateNotNull
    private Integer activityid;

    /**
     * 设备类型（1-安卓 2-ios 3-web）
     */
    @DefaultValue("1")
    @ValidateNotNull
    private String appos;

    /**
     * 是否是微信（1是0否）
     */
    @DefaultValue("0")
    @ValidateNotNull
    private Integer ua;

    /**
     * 是否为小程序端（1是0否）
     */
    @DefaultValue("0")
    @ValidateNotNull
    private String device;

    /**
     * 请求ip地址
     */
    private String ipaddress;

    public String getPositionId() {
        return StringUtils.join(new Object []{appkey, business.replaceAll("ad-|money-", "")}, "-");
    }

    public Integer getScene() {
        return scene;
    }

    public void setScene(Integer scene) {
        this.scene = scene;
    }

    public String getAppkey() {
        return appkey;
    }

    public void setAppkey(String appkey) {
        this.appkey = appkey;
    }

    public Integer getAppEntrance() {
        return appEntrance;
    }

    public void setAppEntrance(Integer appEntrance) {
        this.appEntrance = appEntrance;
    }

    public String getUid() {
        return uid;
    }

    public void setUid(String uid) {
        this.uid = uid;
    }

    public String getBusiness() {
        return business;
    }

    public void setBusiness(String business) {
        this.business = business;
    }

    public String getI() {
        return i;
    }

    public void setI(String i) {
        this.i = i;
    }

    public String getF() {
        return f;
    }

    public void setF(String f) {
        this.f = f;
    }

    public Integer getActivityid() {
        return activityid;
    }

    public void setActivityid(Integer activityid) {
        this.activityid = activityid;
    }

    public String getAppos() {
        return appos;
    }

    public void setAppos(String appos) {
        this.appos = appos;
    }

    public Integer getUa() {
        return ua;
    }

    public void setUa(Integer ua) {
        this.ua = ua;
    }

    public String getDevice() {
        return device;
    }

    public void setDevice(String device) {
        this.device = device;
    }

    public String getIpaddress() {
        return ipaddress;
    }

    public void setIpaddress(String ipaddress) {
        this.ipaddress = ipaddress;
    }

    @Override
    public String toString() {
        return "AwardDto{" +
                "scene=" + scene +
                ", appkey='" + appkey + '\'' +
                ", appEntrance=" + appEntrance +
                ", uid='" + uid + '\'' +
                ", business='" + business + '\'' +
                ", imei='" + i + '\'' +
                ", idfa='" + f + '\'' +
                ", activityid=" + activityid +
                ", appos='" + appos + '\'' +
                ", ua=" + ua +
                ", device='" + device + '\'' +
                ", ipaddress='" + ipaddress + '\'' +
                '}';
    }
}

==> adsprod-facade-1.2.65-sources.jar: com/bxm/adsprod/facade/award/AwardDto.java <==
package com.bxm.adsprod.facade.award;

import com.bxm.warcar.validate.annotation.DefaultValue;
import com.bxm.warcar.validate.annotation.ValidateImeiOrIdfa;
import com.bxm.warcar.validate.annotation.ValidateLength;
import com.bxm.warcar.validate.annotation.ValidateNotNull;
import org.apache.commons.lang3.StringUtils;

import java.io.Serializable;

/**
 * 抽奖数据传输对象
 *
 * @ClassName AwardDto
 * @CopyRright (c) 2018-bxm：杭州微财网络科技有限公司
 * @Author kk.xie
 * @Date 2018/7/20 18:15
 * @Version 1.0
 * @Modifier kk.xie
 * @Modify Date 2018/7/20 18:15
 **/
public class AwardDto implements Serializable{
    private static final long serialVersionUID = 2955004102853948797L;

    /**
     *  弹窗类型  0-出券弹窗 1-首页弹窗 2-挽留弹窗
     */
    @DefaultValue("0")
    @ValidateNotNull
    private Integer scene;

    /**
     * 媒体
     */
    @DefaultValue("mistake_appKey")
    @ValidateLength(min = 32, max = 32)
    private String appkey;

    /**
     * 渠道
     */
    @DefaultValue("1")
    @ValidateNotNull
    private Integer appEntrance;

    /**
     * 用户ID
     */
    @DefaultValue("mistake_uid")
    @ValidateNotNull
    private String uid;

    /**
     * 渠道
     */
    @DefaultValue("mistake_biz")
    @ValidateNotNull
    private String business;

    /**
     * IMEI 安卓唯一标识码
     */
    @ValidateImeiOrIdfa
    private String i;

    /**
     * IDFA 苹果唯一标识符
     */
    @ValidateImeiOrIdfa
    private String f;

    /**
     * 活动ID
     */
    @DefaultValue("0")
    @ValidateNotNull
    private Integer activityid;

    /**
     * 设备类型（1-安卓 2-ios 3-web）
     */
    @DefaultValue("1")
    @ValidateNotNull
    private String appos;

    /**
     * 是否是微信（1是0否）
     */
    @DefaultValue("0")
    @ValidateNotNull
    private Integer ua;

    /**
     * 是否为小程序端（1是0否）
     */
    @DefaultValue("0")
    @ValidateNotNull
    private String device;

    /**
     * 请求ip地址
     */
    private String ipaddress;

    /**
     * 是否需要考虑素材
     * js/api 需要考虑素材
     * h5  不需要素材素材
     */
    private boolean needMaterials;

    /**
     * 是否为特殊活动（如卡包（0不是，1是））
     */
    private String isSpecial  ;

    public String getPositionId() {
        return StringUtils.join(new Object []{appkey, business.replaceAll("ad-|money-", "")}, "-");
    }

    public Integer getScene() {
        return scene;
    }

    public void setScene(Integer scene) {
        this.scene = scene;
    }

    public String getAppkey() {
        return appkey;
    }

    public void setAppkey(String appkey) {
        this.appkey = appkey;
    }

    public Integer getAppEntrance() {
        return appEntrance;
    }

    public void setAppEntrance(Integer appEntrance) {
        this.appEntrance = appEntrance;
    }

    public String getUid() {
        return uid;
    }

    public void setUid(String uid) {
        this.uid = uid;
    }

    public String getBusiness() {
        return business;
    }

    public void setBusiness(String business) {
        this.business = business;
    }

    public String getIsSpecial() {
        if(StringUtils.isBlank(isSpecial)){
            return "1";
        }
        return isSpecial;
    }

    public void setIsSpecial(String isSpecial) {
        this.isSpecial = isSpecial;
    }

    public String getI() {
        return i;
    }

    public void setI(String i) {
        this.i = i;
    }

    public String getF() {
        return f;
    }

    public void setF(String f) {
        this.f = f;
    }

    public Integer getActivityid() {
        return activityid;
    }

    public void setActivityid(Integer activityid) {
        this.activityid = activityid;
    }

    public String getAppos() {
        return appos;
    }

    public void setAppos(String appos) {
        this.appos = appos;
    }

    public Integer getUa() {
        return ua;
    }

    public void setUa(Integer ua) {
        this.ua = ua;
    }

    public String getDevice() {
        return device;
    }

    public void setDevice(String device) {
        this.device = device;
    }

    public String getIpaddress() {
        return ipaddress;
    }

    public void setIpaddress(String ipaddress) {
        this.ipaddress = ipaddress;
    }

    public boolean isNeedMaterials() {
        return needMaterials;
    }

    public void setNeedMaterials(boolean needMaterials) {
        this.needMaterials = needMaterials;
    }

    @Override
    public String toString() {
        return "AwardDto{" +
                "scene=" + scene +
                ", appkey='" + appkey + '\'' +
                ", appEntrance=" + appEntrance +
                ", uid='" + uid + '\'' +
                ", business='" + business + '\'' +
                ", i='" + i + '\'' +
                ", f='" + f + '\'' +
                ", activityid=" + activityid +
                ", appos='" + appos + '\'' +
                ", ua=" + ua +
                ", device='" + device + '\'' +
                ", ipaddress='" + ipaddress + '\'' +
                ", needMaterials=" + needMaterials +
                '}';
    }

}
